"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var axios_1 = __importDefault(require("axios"));
var Request = /** @class */ (function () {
    function Request(config) {
        var _this = this;
        if (config === void 0) { config = {}; }
        this.service = axios_1.default;
        this.config = config;
        this.service.defaults.withCredentials = true;
        this.service.defaults.headers.common['X-Requested-With'] = 'XMLHttpRequest';
        this.service.interceptors.response.use(function (response) { return Promise.resolve(response); }, function (error) {
            var _a, _b;
            // 419 error means that the CSRF token has timed out
            // in that case if the config autoRequestCsrfCookie is set to 'true',
            // we try to receive new token and retry the request.
            if (error.response.status === 419
                && _this.config.autoRequestCsrfCookie
                && typeof _this.config.csrfCookieUrl !== 'undefined') {
                _this.get(_this.config.csrfCookieUrl)
                    .then(function () { return _this.service.request(error.config); });
            }
            (_b = (_a = _this.config.errorCallbacks) === null || _a === void 0 ? void 0 : _a.find(function (callback) { return callback.errorCode === error.response.status; })) === null || _b === void 0 ? void 0 : _b.callback(error);
            return Promise.reject(error);
        });
    }
    Request.getInstance = function () {
        if (typeof this.instance !== 'undefined') {
            return this.instance;
        }
        this.instance = new Request(this.instanceConfig);
        return this.instance;
    };
    Request.setConfig = function (config) {
        this.instanceConfig = __assign(__assign({}, this.instanceConfig), config);
    };
    // eslint-disable-next-line max-len
    Request.prototype.get = function (url, config) {
        return this.service.get(url, config);
    };
    // eslint-disable-next-line max-len
    Request.prototype.post = function (url, data, config) {
        return this.service.post(url, data, config);
    };
    // eslint-disable-next-line max-len
    Request.prototype.patch = function (url, data, config) {
        return this.service.patch(url, data, config);
    };
    // eslint-disable-next-line max-len
    Request.prototype.put = function (url, data, config) {
        return this.service.put(url, data, config);
    };
    // eslint-disable-next-line max-len
    Request.prototype.delete = function (url, config) {
        return this.service.delete(url, config);
    };
    Request.instanceConfig = {
        autoRequestCsrfCookie: true,
        csrfCookieUrl: '/sanctum/csrf-cookie',
        errorCallbacks: [],
    };
    return Request;
}());
exports.default = Request;
//# sourceMappingURL=Request.js.map